# unryo-collector

The unryo-collector contains everything to run a standalone Unryo solution. It has the collectors for events & metrics, the databases, analytics engine and frontend.

## TL;DR

```console
curl -LO https://downloads.unryo.com/unryo-collector-1.0.0.tgz
tar xvzf unryo-collector-1.0.0.tgz
helm install --create-namespace --namespace unryo my-release --set "config.secret.unryoToken=REPLACE_ME_BY_YOUR_UNRYO_TOKEN,config.secret.unryoVaultToken=REPLACE_ME_BY_YOUR_UNRYO_VAULT_TOKEN" ./unryo-collector
```


## Installing the Chart
To install the chart with the release name `my-release` you will need to [download the helm chart](https://downloads.unryo.com/unryo-collector-1.0.0.tgz) and get your Unryo Token values.

The *Unryo Token* and *Vault Token* can be reused from an existing deployment or [obtained from the portal](https://docs.unryo.com/#/00_Introduction/30_quick_start_onprem?id=step-1-all-in-one-installation).

```console
helm install --create-namespace --namespace unryo my-release --set "config.secret.unryoToken=REPLACE_ME_BY_YOUR_UNRYO_TOKEN,config.secret.unryoVaultToken=REPLACE_ME_BY_YOUR_UNRYO_VAULT_TOKEN" ./unryo-collector
```

The command deploys Unryo Fullstack on the Kubernetes cluster in the default configuration. The [Parameters](#parameters) section lists the parameters that can be configured during installation.

> **Tip**: List all releases using `helm list`

## Uninstalling the Chart

To uninstall/delete the `my-release` deployment:

```console
helm delete my-release
```

## Parameters


| NAME                                 | DESCRIPTION                                    | DEFAULT VALUE |
| ------------------------------------ | ---------------------------------------------- | ------------- |
| `config.broker`                      | Unryo broker url used for the orchestration    | `https://broker.unryo.com` |
| `config.secret.unryoToken`           | Unryo token for the namespace                  | `REPLACE_ME_BY_YOUR_UNRYO_TOKEN` |
| `config.storageClass`                | If not set use the default storageClass ; otherwise it will use the configured `storageClass` | `{}` |
| `monitoring.dockerMonitoringFromK8s` | Do you want to monitor docker directly from kubernetes ? | `false`
| `datacollection.enabled`             | Do you want to enable metrics and events collection | `true` |
| `datacollection.nodeSelector`        | Defines what nodes would be selected for pods ; leave as blank to use all nodes or give a label (e.g. `node-role.kubernetes.io/master: ""` |  |
| `datacollection.tolerations`         | Defines tolerations that would be applied to node for the deployments | |
| `images.imagePullPolicy`             | Default pull policy for all the images         | `Always` |
| `images.imagePullSecrets`            | In case you use a private repo that is secured with credentials, you can set the imagePullSecret here| `{}` | 
| `images.busybox`                     | This value and the other ones available from the `values.yaml` file gives the option to specify a different registry that docker.io (e.g. in case you have a private one) | `docker.io/busybox:1.28` |
| `services.type`                      | How do you want to expose the portal URL to the external world | `LoadBalancer` |
| `k8sMonitoringPermissions.enabled`   | Do you want to grant permissions necessary to monitor Kubernetes | `true` |
| `k8sMonitoringPermissions.create`    | Do you want to create new Cluster Role for Kubernetes monitoring | `true` |
| `k8sMonitoringPermissions.roleName`  | Name of Cluster Role for Kubernetes monitoring. If empty and create is true, a unique name is generated. | "" |
